"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var XmlAttributeNames_1 = require("../Core/XmlAttributeNames");
var XmlElementNames_1 = require("../Core/XmlElementNames");
/**
 * Represents an error returned by the Autodiscover service.
 * @sealed
 */
var AutodiscoverError = /** @class */ (function () {
    /**
     * Initializes a new instance of the **AutodiscoverError** class.
     */
    function AutodiscoverError() {
    }
    Object.defineProperty(AutodiscoverError.prototype, "Time", {
        /**
         * Gets the time when the error was returned.
         */
        get: function () {
            return this.time;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverError.prototype, "Id", {
        /**
         * Gets a hash of the name of the computer that is running Microsoft Exchange Server that has the Client Access server role installed.
         */
        get: function () {
            return this.id;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverError.prototype, "ErrorCode", {
        /**
         * Gets the error code.
         */
        get: function () {
            return this.errorCode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverError.prototype, "Message", {
        /**
         * Gets the error message.
         */
        get: function () {
            return this.message;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverError.prototype, "DebugData", {
        /**
         * Gets the debug data.
         */
        get: function () {
            return this.debugData;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * Parses the XML Js Object creates an Autodiscover error.
     *
     * @param   {any}   jsObject   The object.
     * @return  {AutodiscoverError}            An Autodiscover error.
     */
    AutodiscoverError.prototype.Parse = function (jsObject) {
        var error = new AutodiscoverError();
        error.time = jsObject[XmlAttributeNames_1.XmlAttributeNames.Time] || null;
        error.id = jsObject[XmlAttributeNames_1.XmlAttributeNames.Id] || null;
        error.errorCode = parseInt(jsObject[XmlElementNames_1.XmlElementNames.ErrorCode]) || 0;
        error.message = jsObject[XmlElementNames_1.XmlElementNames.Message] || null;
        error.debugData = jsObject[XmlElementNames_1.XmlElementNames.DebugData] || null;
        return error;
    };
    return AutodiscoverError;
}());
exports.AutodiscoverError = AutodiscoverError;
//# sourceMappingURL=AutodiscoverError.js.map