"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AutodiscoverErrorCode_1 = require("../Enumerations/AutodiscoverErrorCode");
var XmlElementNames_1 = require("../Core/XmlElementNames");
/**
 * Represents an error from a GetDomainSettings request.
 * @sealed
 */
var DomainSettingError = /** @class */ (function () {
    /**
     * @internal Initializes a new instance of the **DomainSettingError** class.
     */
    function DomainSettingError() {
    }
    Object.defineProperty(DomainSettingError.prototype, "ErrorCode", {
        /**
         * Gets the error code.
         */
        get: function () {
            return this.errorCode;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DomainSettingError.prototype, "ErrorMessage", {
        /**
         * Gets the error message.
         */
        get: function () {
            return this.errorMessage;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(DomainSettingError.prototype, "SettingName", {
        /**
         * Gets the name of the setting.
         */
        get: function () {
            return this.settingName;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @internal Loads settings error from XML jsObject.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    DomainSettingError.prototype.LoadFromXmlJsObject = function (jsObject) {
        var errorstring = jsObject[XmlElementNames_1.XmlElementNames.ErrorCode];
        this.errorCode = AutodiscoverErrorCode_1.AutodiscoverErrorCode[errorstring] || AutodiscoverErrorCode_1.AutodiscoverErrorCode.NoError;
        this.errorMessage = jsObject[XmlElementNames_1.XmlElementNames.ErrorMessage] || null;
        this.settingName = jsObject[XmlElementNames_1.XmlElementNames.SettingName] || null;
    };
    return DomainSettingError;
}());
exports.DomainSettingError = DomainSettingError;
//# sourceMappingURL=DomainSettingError.js.map