"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AutodiscoverErrorCode_1 = require("../../Enumerations/AutodiscoverErrorCode");
var XmlElementNames_1 = require("../../Core/XmlElementNames");
/**
 * Represents the base class for all responses returned by the Autodiscover service.
 */
var AutodiscoverResponse = /** @class */ (function () {
    function AutodiscoverResponse() {
        this.errorCode = AutodiscoverErrorCode_1.AutodiscoverErrorCode.NoError;
    }
    Object.defineProperty(AutodiscoverResponse.prototype, "ErrorCode", {
        /**
         * Gets the error code that was returned by the service.
         */
        get: function () {
            return this.errorCode;
        },
        /** @internal */
        set: function (value) {
            this.errorCode = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverResponse.prototype, "ErrorMessage", {
        /**
         * Gets the error message that was returned by the service.
         */
        get: function () {
            return this.errorMessage;
        },
        /** @internal */
        set: function (value) {
            this.errorMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(AutodiscoverResponse.prototype, "RedirectionUrl", {
        /**
         * @internal Gets or sets the redirection URL.
         */
        get: function () {
            return this.redirectionUrl;
        },
        set: function (value) {
            this.redirectionUrl = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @internal Loads service object from XML.
     *
     * @param   {any} responseObject  Json Object converted from XML.
     */
    AutodiscoverResponse.prototype.LoadFromXmlJsObject = function (jsObject) {
        var errorstring = jsObject[XmlElementNames_1.XmlElementNames.ErrorCode];
        this.errorCode = AutodiscoverErrorCode_1.AutodiscoverErrorCode[errorstring];
        var errmsg = jsObject[XmlElementNames_1.XmlElementNames.ErrorMessage];
        this.errorMessage = errmsg;
    };
    return AutodiscoverResponse;
}());
exports.AutodiscoverResponse = AutodiscoverResponse;
//# sourceMappingURL=AutodiscoverResponse.js.map