"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var AutodiscoverErrorCode_1 = require("../Enumerations/AutodiscoverErrorCode");
var XmlElementNames_1 = require("../Core/XmlElementNames");
/**
 * Represents an error from a GetUserSettings request.
 * @sealed
 */
var UserSettingError = /** @class */ (function () {
    function UserSettingError(errorCode, errorMessage, settingName) {
        if (errorCode === void 0) { errorCode = AutodiscoverErrorCode_1.AutodiscoverErrorCode.NoError; }
        if (errorMessage === void 0) { errorMessage = null; }
        if (settingName === void 0) { settingName = null; }
        this.errorCode = errorCode;
        this.errorMessage = errorMessage;
        this.settingName = settingName;
    }
    Object.defineProperty(UserSettingError.prototype, "ErrorCode", {
        /**
         * Gets the error code.
         */
        get: function () {
            return this.errorCode;
        },
        /** @internal */
        set: function (value) {
            this.errorCode = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UserSettingError.prototype, "ErrorMessage", {
        /**
         * Gets the error message.
         */
        get: function () {
            return this.errorMessage;
        },
        /** @internal */
        set: function (value) {
            this.errorMessage = value;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(UserSettingError.prototype, "SettingName", {
        /**
         * Gets the name of the setting.
         */
        get: function () {
            return this.settingName;
        },
        /** @internal */
        set: function (value) {
            this.settingName = value;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @internal Loads settings error from XML jsObject.
     *
     * @param   {any} jsObject  Json Object converted from XML.
     */
    UserSettingError.prototype.LoadFromXmlJsObject = function (jsObject) {
        var errorstring = jsObject[XmlElementNames_1.XmlElementNames.ErrorCode];
        this.errorCode = AutodiscoverErrorCode_1.AutodiscoverErrorCode[errorstring] || AutodiscoverErrorCode_1.AutodiscoverErrorCode.NoError;
        this.errorMessage = jsObject[XmlElementNames_1.XmlElementNames.ErrorMessage] || null;
        this.settingName = jsObject[XmlElementNames_1.XmlElementNames.SettingName] || null;
    };
    return UserSettingError;
}());
exports.UserSettingError = UserSettingError;
//# sourceMappingURL=UserSettingError.js.map